@@ -17,7 +17,7 @@ use Net::Statsd::Tiny::Types -types;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.2.0';
 
 
 has host => (
@@ -94,7 +94,7 @@ BEGIN {
         gauge     => [ 'g',  Gauge | PosInt ],
         histogram => [ 'h',  PosNum ],
         meter     => [ 'm',  PosInt ],
-        timing    => [ 'ms', PosNum ],
+        timing    => [ 'ms', PosNum, 1 ],
     );
 
     foreach my $name ( keys %PROTOCOL ) {
@@ -219,7 +219,7 @@ Net::Statsd::Tiny - A tiny StatsD client
 
 =head1 VERSION
 
-version v0.1.1
+version v0.2.0
 
 =head1 SYNOPSIS
 
@@ -356,7 +356,7 @@ by that amount.
 
 =head2 C<timing>
 
-  $stats->timing( $metric, $value );
+  $stats->timing( $metric, $value, $rate );
 
 This logs a "timing" in milliseconds, so that statistics about the
 metric can be gathered. The C<$value> must be positive number,
@@ -366,6 +366,10 @@ In actually, any values can be logged, and this is often used as a
 generic histogram for non-timing values (especially since many StatsD
 daemons do not support the L</histogram> metric type).
 
+If a C<$rate> is specified and less than 1, then a sampling rate will
+be added. C<$rate> must be between 0 and 1.  Note that sampling
+rates for timings may not be supported by all statsd servers.
+
 =head2 C<timing_ms>
 
 This is an alias for L</timing>, for compatability with
